@@ -1,10 +1,10 @@
 
-from .basic import DependencyGraph, Variable, compute_sequential, Stopwatch, \
+from .basic import DependencyGraph, Place, compute_sequential, Stopwatch, \
         print_value, assign
 
 from .aio import async_compute_sequential, async_compute_concurrent, \
         async_compute_concurrent_simple, timer
 
-from .mod import ModClock, ModVariable, ModPrinter
+from .mod import ModClock, ModPlace, ModPrinter
 
 from .flow import compute_flow, cancel_flow
